package com.aitrainer.api.test.diet

import com.aitrainer.api.model.diet.DietSensitivity
import com.aitrainer.api.test.Tokenizer
import com.google.gson.Gson
import org.junit.jupiter.api.BeforeAll
import org.junit.jupiter.api.Test
import org.junit.jupiter.api.TestInstance
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.MediaType
import org.springframework.test.web.servlet.MockMvc
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders.post
import org.springframework.test.web.servlet.result.MockMvcResultMatchers.*

@SpringBootTest
@AutoConfigureMockMvc
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
class DietSensitivityTest {

    @Autowired
    lateinit var mockMvc: MockMvc

    private var authToken: String? = ""

    @BeforeAll
    fun initTest() {
        authToken = Tokenizer.getToken()
    }

    private val dietSensitivity = DietSensitivity(1, name = "Nut Allergy")
    private val dietSensitivity2 = DietSensitivity(2, name = "Penicillin sensitivity")

    @Test
    fun `insert diet sensitivity successfully`() {

        val gson = Gson()

        mockMvc.perform(
            post("/api/diet_sensitivity")
                .contentType(MediaType.APPLICATION_JSON)
                .header("Authorization", "Bearer $authToken")
                .content(gson.toJson(dietSensitivity))
            )
            .andExpect(status().isOk)
            .andExpect(jsonPath("$.name").value("Nut Allergy"))

        mockMvc.perform(
            post("/api/diet_sensitivity")
                .contentType(MediaType.APPLICATION_JSON)
                .header("Authorization", "Bearer $authToken")
                .content(gson.toJson(dietSensitivity2))
            )
        .andExpect(status().isOk)
    }

    @Test
    fun `get all diet sensitivity successfully`() {

        mockMvc.perform(get("/api/diet_sensitivity")
            .header("Authorization", "Bearer $authToken")
            .contentType(MediaType.APPLICATION_JSON))
            .andExpect(status().isOk)
            .andExpect(jsonPath("$.[0].name").value("Nut Allergy"))
            .andExpect(jsonPath("$.[1].name").value("Penicillin sensitivity"))
    }

}
